import numpy as np
import numpy.random as nr
import scipy.stats as ss
import pystan
import pickle
import matplotlib.pyplot as plt
import seaborn as sb

StanCode = """
data {
    int N;
    real x1[N];
    real x2[N];
}
parameters {
    real mu1;
    real mu2;
    real<lower = 0.0> sgm;
}
model {
    mu1 ~ normal(0.0, 1000.0);
    mu2 ~ normal(0.0, 1000.0);
    sgm ~ exponential(0.001);
    for (i in 1:N){
        x1[i] ~ normal(mu1, sgm);
        x2[i] ~ normal(mu2, sgm);
    }
}
"""

sm = pystan.StanModel(model_code = StanCode)
with open('sm.pkl', 'wb') as f:
    pickle.dump(sm, f)


mu1 = 103.0
mu2 = 100.0
sgm = 10.0

n_trials = 100

s_size = [5, 200]
ddata = dict()
X = []
G = []

for v_size in s_size:

    p_eff = []

    for t in range(n_trials):
        if t % 10 == 0:
            print('Trial {} started.'.format(t))

        x1 = nr.normal(loc = mu1, scale = sgm, size = v_size)
        x2 = nr.normal(loc = mu2, scale = sgm, size = v_size)

        Data = {'N': len(x1), 'x1': x1, 'x2': x2}
        sm = pickle.load(open('sm.pkl', 'rb'))
        fit = sm.sampling(data = Data,n_jobs = 1)
        
        smpl_mu1 = fit['mu1']
        smpl_mu2 = fit['mu2']
        smpl_mu12 = smpl_mu1 - smpl_mu2
        tmp = np.abs(smpl_mu12) < 5
        p_eff.append(tmp.mean())
        
        if t < 10:
            sb.kdeplot(smpl_mu12)

    X += p_eff
    G += ['{}'.format(v_size)] * len(p_eff)

    plt.title('Posterior Distributions\n' +
              'N = {}'.format(v_size), fontsize = 16)
    plt.xlabel('$\mu_1$ - $\mu_2$', fontsize = 14)
    plt.yticks([])
    plt.show()

sb.boxplot(x = 'G', y = 'X', data = {'G':G, 'X':X}, order = ['5', '200'])
sb.stripplot(x = 'G', y = 'X', data = {'G':G, 'X':X}, order = ['5', '200'], color = 'k')
plt.xlabel('N', fontsize = 14)
plt.ylabel('P', fontsize = 14)
plt.title('Prob(|$\mu_1$ - $\mu_2$| < 5)\nfor posterior distributions', fontsize = 16) 
plt.show()
