import numpy as np
import numpy.random as nr
import scipy.stats as ss
import matplotlib.pyplot as plt
import seaborn as sb


mu1 = 103.0
mu2 = 100.0
sgm = 10.0

n_trials = 1000
n_samples = [5, 200]
p_vals = []
for s_size in range(2):
    p_vals.append([])
    n = n_samples[s_size]
    for t in range(n_trials):
        x1 = nr.normal(loc = mu1, scale = sgm, size = n)
        x2 = nr.normal(loc = mu2, scale = sgm, size = n)
        results = ss.ttest_ind(x1, x2)
        p_vals[s_size].append(results.pvalue)

X = []
G = []
for s_size in range(2):
    X += p_vals[s_size]
    G += ['{}'.format(n_samples[s_size])] * len(p_vals[s_size])

p_05 = []
for s_size in range(2):
    p = [np.array(p_vals[s_size]) < 0.05]
    p_05.append(np.array(p).mean())
sb.boxplot(x = 'G', y = 'X', data = {'X': X, 'G': G}, order = ['5', '200'])
plt.title(('Prop(p-val < 0.05) = {0:.3}: N = {1:}  \n' +
           'Prop(p-val < 0.05) = {2:.3}: N = {3:}').format
          (p_05[0], n_samples[0], p_05[1], n_samples[1]), fontsize = 16)
plt.xlabel('N', fontsize = 16)
plt.ylabel('p-value', fontsize = 14)
plt.show()

